@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Login Screen
 #
-# $Id: lonlogin.pm,v 1.87 2007/01/14 02:00:04 raeburn Exp $
+# $Id: lonlogin.pm,v 1.93 2007/04/17 15:44:58 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -128,17 +128,18 @@ ENDFAILED
                   $r->dir_config('lonIconsURL');
     my $domain = &Apache::lonnet::default_login_domain();
     if (($env{'form.domain'}) && 
-	 ($Apache::lonnet::domaindescription{$env{'form.domain'}})) {
+	(&Apache::lonnet::domain($env{'form.domain'},'description'))) {
 	$domain=$env{'form.domain'};
     }
     my $role    = $r->dir_config('lonRole');
     my $loadlim = $r->dir_config('lonLoadLim');
+    my $servadm = $r->dir_config('lonAdmEMail');
     my $lonhost = $r->dir_config('lonHostID');
     my $tabdir  = $r->dir_config('lonTabDir');
     my $include = $r->dir_config('lonIncludes');
     my $expire  = $r->dir_config('lonExpire');
     my $version = $r->dir_config('lonVersion');
-    my $host_name = $Apache::lonnet::hostname{$lonhost};
+    my $host_name = &Apache::lonnet::hostname($lonhost);
 
 # --------------------------------------------- Default values for login fields
 
@@ -200,33 +201,36 @@ ENDFAILED
 	my $last;
         foreach my $hostid (sort
 			    {
-				$Apache::lonnet::hostname{$a} cmp
-				    $Apache::lonnet::hostname{$b};
+				&Apache::lonnet::hostname($a) cmp
+				    &Apache::lonnet::hostname($b);
 			    }
 			    keys(%Apache::lonnet::spareid)) {
             next if ($hostid eq $lonhost);
-            next if ($last eq $Apache::lonnet::hostname{$hostid});
+	    my $hostname = &Apache::lonnet::hostname($hostid);
+	    next if ($last eq $hostname);
             $spares.='<br /><font size="+1"><a href="http://'.
-                $Apache::lonnet::hostname{$hostid}.
+                $hostname.
                 '/adm/login?domain='.$authdomain.'">'.
-                $Apache::lonnet::hostname{$hostid}.'</a>'.
+                $hostname.'</a>'.
                 ' (preferred)</font>'.$/;
-	    $last=$Apache::lonnet::hostname{$hostid};
+	    $last=$hostname;
         }
         $spares.= '<br />';
+	my %all_hostnames = &Apache::lonnet::all_hostnames();
         foreach my $hostid (sort
 			    {
-				$Apache::lonnet::hostname{$a} cmp
-				    $Apache::lonnet::hostname{$b};
+				&Apache::lonnet::hostname($a) cmp
+				    &Apache::lonnet::hostname($b);
 			    }
-			    keys(%Apache::lonnet::hostname)) {
+			    keys(%all_hostnames)) {
             next if ($hostid eq $lonhost || $Apache::lonnet::spareid{$hostid});
-            next if ($last eq $Apache::lonnet::hostname{$hostid});
+	    my $hostname = &Apache::lonnet::hostname($hostid);
+            next if ($last eq $hostname);
             $spares.='<br /><a href="http://'.
-                $Apache::lonnet::hostname{$hostid}.
+                $hostname.
                 '/adm/login?domain='.$authdomain.'">'.
-                $Apache::lonnet::hostname{$hostid}.'</a>';
-	    $last=$Apache::lonnet::hostname{$hostid};
+                $hostname.'</a>';
+	    $last=$hostname;
         }
 	$r->print(<<ENDTROUBLE);
 <html>
@@ -242,8 +246,7 @@ ENDTROUBLE
     }
 
 # ----------------------------------------------- Apparently we are in business
-
-    my $domainlogo=&Apache::loncommon::domainlogo($domain);
+    $servadm=~s/\,/\<br \/\>/g;
 
 # --------------------------------------------------- Print login screen header
     $r->print(<<ENDHEADER);
@@ -275,6 +278,11 @@ ENDHEADER
       ($fullgraph?&Apache::loncommon::designparm('login.sidebg',$domain):'#FFFFFF');
     my $logo=&Apache::loncommon::designparm('login.logo',$domain);
     my $img=&Apache::loncommon::designparm('login.img',$domain);
+    my $domainlogo=&Apache::loncommon::domainlogo($domain);
+    my $showadminmail=&Apache::loncommon::designparm('login.adminmail',                                                      $domain);
+    my $showcoursecat =
+        &Apache::loncommon::designparm('login.coursecatalog',$domain);
+
 
 # ----------------------------------------------------------------------- Texts
 
@@ -292,6 +300,7 @@ my %lt=&Apache::lonlocal::texthash(
 		  'log' => 'Log in',
 		  'help' => 'Log-in Help',
 		  'serv' => 'Server',
+                  'servadm' => 'Server Administration',
                   'helpdesk' => 'Contact Helpdesk',
                   'forgotpw' => 'Forgot password?');
 # -------------------------------------------------- Change password field name
@@ -376,6 +385,10 @@ ENDSCRIPT
    <input type="hidden" name="localres" value="$env{'form.localres'}" />
   </form>
 ENDSERVERFORM
+    my $coursecatalog;
+    if (($showcoursecat eq '') || ($showcoursecat)) {
+        $coursecatalog = &coursecatalog_link($lt{'catalog'});
+    }
     if ($fullgraph) { $r->print(<<ENDTOP);
   <!-- The LON-CAPA Header -->
   <tr>
@@ -412,11 +425,7 @@ ENDSERVERFORM
      <tr>
       <td>&nbsp;</td>
       <td><a href="/adm/about.html"><b>$lt{'about'}</b></a></td>
-     </tr>
-     <tr>
-      <td>&nbsp;</td>
-      <td><a href="/adm/coursecatalog"><b>$lt{'catalog'}</b></a></td>
-     </tr>
+     </tr>$coursecatalog
      <tr>
       <td colspan="2">&nbsp;</td>
      </tr>
@@ -475,15 +484,15 @@ ENDNOOPT
      <table border=0 cellspacing=0 cellpadding=0>
       <tr><td bgcolor="$sidebg" colspan=2><img src="$iconpath/$lt{'auth'}" alt="User Authentication" /></td></tr>
       <tr>
-       <td bgcolor="$mainbg"><br /><font size=-1><b>&nbsp;&nbsp;&nbsp;$lt{'un'}:</b></font></td>
+       <td bgcolor="$mainbg"><br /><font size=-1><b>&nbsp;&nbsp;&nbsp;<label for="uname">$lt{'un'}</label>:</b></font></td>
        <td bgcolor="$mainbg"><br /><input type="text" name="uname" size="10" value="$authusername" /></td>
       </tr>
       <tr>
-       <td bgcolor="$mainbg"><font size=-1><b>&nbsp;&nbsp;&nbsp;$lt{'pw'}:</b></font></td>
+       <td bgcolor="$mainbg"><font size=-1><b>&nbsp;&nbsp;&nbsp;<label for="upass$now">$lt{'pw'}</label>:</b></font></td>
        <td bgcolor="$mainbg"><input type="password" name="upass$now" size="10" /></td>
       </tr>
       <tr>
-       <td bgcolor="$mainbg"><font size=-1><b>&nbsp;&nbsp;&nbsp;$lt{'dom'}:</b></font></td>
+       <td bgcolor="$mainbg"><font size=-1><b>&nbsp;&nbsp;&nbsp;<label for="udom">$lt{'dom'}</label>:</b></font></td>
        <td bgcolor="$mainbg"><input type="text" name="udom" size="10" value="$authdomain" /></td>
       </tr>
       <tr>
@@ -505,7 +514,8 @@ ENDNOOPT
 ENDLOGIN
     if ($fullgraph) {
         my $helpdeskscript;
-        my $contactblock = &contactdisplay(\%lt,$version,$authdomain,\$helpdeskscript);
+        my $contactblock = &contactdisplay(\%lt,$servadm,$showadminmail,
+                                  $version,$authdomain,\$helpdeskscript);
 	$r->print(<<ENDDOCUMENT);
    </td>
 
@@ -601,13 +611,17 @@ ENDDOCUMENT
 }
 
 sub contactdisplay {
-    my ($lt,$version,$authdomain,$helpdeskscript) = @_;
+    my ($lt,$servadm,$showadminmail,$version,$authdomain,$helpdeskscript) = @_;
     my $contactblock;
     my $showhelpdesk = 0;
     my $requestmail = $Apache::lonnet::perlvar{'lonSupportEMail'};
     if ($requestmail =~ m/^[^\@]+\@[^\@]+$/) {
         $showhelpdesk = 1;
     }
+    if ($servadm && $showadminmail) {
+        $contactblock .= '<b>&nbsp;&nbsp;&nbsp;'.$$lt{'servadm'}.':</b><br />'.
+                         '<tt>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;'.$servadm.'</tt><br />&nbsp;<br />';
+    }
     if ($showhelpdesk) {
         $contactblock .= '<b>&nbsp;&nbsp;&nbsp;<a href="javascript:helpdesk()"><font size="+1">'.$lt->{'helpdesk'}.'</font></a></b><br />';
         my $thisurl = &escape('/adm/login');
@@ -649,5 +663,15 @@ sub loginhelpdisplay {
     return;
 }
 
+sub coursecatalog_link {
+    my ($linkname) = @_;
+    return <<"END";
+     <tr>
+      <td>&nbsp;</td>
+      <td><a href="/adm/coursecatalog"><b>$linkname</b></a></td>
+     </tr>
+END
+}
+
 1;
 __END__
