@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # caparesponse definition
 #
-# $Id: caparesponse.pm,v 1.198.2.3 2007/01/25 21:03:45 albertel Exp $
+# $Id: caparesponse.pm,v 1.214 2007/05/22 00:45:43 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -33,6 +33,7 @@ use Safe::Hole;
 use Apache::lonmaxima();
 use Apache::lonlocal;
 use Apache::lonnet;
+use Apache::response();
 use Storable qw(dclone);
 
 BEGIN {
@@ -60,19 +61,63 @@ sub start_answer {
     if (!defined($type)) { $type = 'ordered' };
     $answer{$cur_name}= { 'type' => $type,
 			  'answers' => [] };
+    if ($target eq 'edit') {
+  	$result.=&Apache::edit::tag_start($target,$token);
+	$result.=&Apache::edit::text_arg('Name:','name',$token);
+	$result.=&Apache::edit::select_arg('Type:','type',
+					   [['ordered',  'Ordered'  ],
+					    ['unordered','Unordered'],],
+					   $token);
+	$result.=&Apache::edit::end_row().&Apache::edit::start_spanning_row();
+    } elsif ($target eq 'modified') {
+	my $constructtag = &Apache::edit::get_new_args($token,$parstack,
+						       $safeeval,'name',
+						       'type');
+	if ($constructtag) {
+	    $result = &Apache::edit::rebuild_tag($token);
+	    $result.= &Apache::edit::handle_insert();
+	}
+    }
     return $result;
 }
 
 sub end_answer {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval)=@_;
     my $result;
+    if ($target eq 'edit') {
+	$result .= &Apache::edit::tag_end();
+    }
+
     undef($cur_name);
     return $result;
 }
 
+sub insert_answer {
+    return '
+        <answer>
+            <value></value>
+        </answer>';
+}
+
 sub start_answergroup {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval)=@_;
     my $result;
+    if ($target eq 'edit') {
+  	$result.=&Apache::edit::tag_start($target,$token);
+	$result.=&Apache::edit::select_arg('Type:','type',
+					   [['ordered',  'Ordered'  ],
+					    ['unordered','Unordered'],],
+					   $token);
+	$result.=&Apache::edit::end_row().&Apache::edit::start_spanning_row();
+    } elsif ($target eq 'modified') {
+	my $constructtag = &Apache::edit::get_new_args($token,$parstack,
+						       $safeeval,'name',
+						       'type');
+	if ($constructtag) {
+	    $result = &Apache::edit::rebuild_tag($token);
+	    $result.= &Apache::edit::handle_insert();
+	}
+    }
     return $result;
 }
 
@@ -87,10 +132,21 @@ sub end_answergroup {
 			    $target,$token,$tagstack,$parstack,$parser,
 			    $safeeval,-2);
 	}
+    } elsif ($target eq 'edit') {
+	$result .= &Apache::edit::tag_end();
     }
     return $result;
 }
 
+sub insert_answergroup {
+    return '
+    <answergroup>
+        <answer>
+            <value></value>
+        </answer>
+    </answergroup>';
+}
+
 sub start_value {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
     my $result;
@@ -103,6 +159,13 @@ sub start_value {
 	
 	push(@{ $answer{$cur_name}{'answers'} },[$bodytext]);
 	
+    } elsif ($target eq 'edit') {
+  	$result.=&Apache::edit::tag_start($target,$token);
+	my $bodytext = &Apache::lonxml::get_all_text("/value",$parser,$style);
+	$result.=&Apache::edit::editline($token->[1],$bodytext,undef,40).
+	    &Apache::edit::end_row();
+    } elsif ($target eq 'modified') {
+	$result=$token->[4].&Apache::edit::modifiedfield('/value',$parser);
     }
     return $result;
 }
@@ -110,9 +173,17 @@ sub start_value {
 sub end_value {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval)=@_;
     my $result;
+    if ($target eq 'edit') {
+	$result = &Apache::edit::end_table();
+    }
     return $result;
 }
 
+sub insert_value {
+    return '
+            <value></value>';
+}
+
 sub start_vector {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
     my $result;
@@ -125,6 +196,13 @@ sub start_vector {
 	    @values = split(',',$values[0]);
 	}
 	push(@{ $answer{$cur_name}{'answers'} },\@values);
+    } elsif ($target eq 'edit') {
+  	$result.=&Apache::edit::tag_start($target,$token);
+	my $bodytext = &Apache::lonxml::get_all_text("/vector",$parser,$style);
+	$result.=&Apache::edit::editline($token->[1],$bodytext,undef,40).
+	    &Apache::edit::end_row();
+    } elsif ($target eq 'modified') {
+	$result=$token->[4].&Apache::edit::modifiedfield('/vector',$parser);
     }
     return $result;
 }
@@ -132,9 +210,17 @@ sub start_vector {
 sub end_vector {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval)=@_;
     my $result;
+    if ($target eq 'edit') {
+	$result = &Apache::edit::end_table();
+    }
     return $result;
 }
 
+sub insert_vector {
+    return '
+            <value></value>';
+}
+
 sub start_array {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
     my $result;
@@ -172,6 +258,7 @@ sub start_numericalresponse {
     &Apache::lonxml::register('Apache::caparesponse',
 			      ('answer','answergroup','value','array','unit',
 			       'vector'));
+    push(@Apache::lonxml::namespace,'caparesponse');
     my $id = &Apache::response::start_response($parstack,$safeeval);
     my $result;
     undef(%answer);
@@ -236,6 +323,13 @@ sub set_answertext {
 	$response_level) = @_;
     &add_in_tag_answer($parstack,$safeeval,$response_level);
 
+    if ($name eq '' || !ref($answer{$name})) {
+	if (ref($answer{$tag_internal_answer_name})) {
+	    $name = $tag_internal_answer_name;
+	} else {
+	    $name = (sort(keys(%answer)))[0];
+	}
+    }
     return if ($name eq '' || !ref($answer{$name}));
 
     my (@formats)=&Apache::lonxml::get_param_var('format',$parstack,
@@ -329,11 +423,11 @@ sub check_submission {
     }
     
     if ($tag eq 'formularesponse') {
-#	if ($$args_ref{'samples'}) {
+	if ($$args_ref{'samples'}) {
 	    $$args_ref{'type'}='fml';
-#	} else {
-#	    $$args_ref{'type'}='math';
-#	}
+	} else {
+	    $$args_ref{'type'}='math';
+	}
     } elsif ($tag eq 'numericalresponse') {
 	$$args_ref{'type'}='float';
     }
@@ -371,14 +465,25 @@ sub add_in_tag_answer {
     my @answer=&Apache::lonxml::get_param_var('answer',$parstack,$safeeval,
 					      $response_level);
     &Apache::lonxml::debug('answer is'.join(':',@answer));
-    if (@answer && defined($answer[0])) {
+    if (@answer && $answer[0] =~ /\S/) {
 	$answer{$tag_internal_answer_name}= {'type' => 'ordered',
 					     'answers' => [\@answer] };
     }
 }
 
+sub capa_formula_fix {
+   my ($expression)=@_;
+   return &Apache::response::implicit_multiplication($expression);
+}
+
 sub end_numericalresponse {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
+
+    &Apache::lonxml::deregister('Apache::caparesponse',
+			      ('answer','answergroup','value','array','unit',
+			       'vector'));
+    pop(@Apache::lonxml::namespace);
+
     my $increment=1;
     my $result = '';
     if (!$Apache::lonxml::default_homework_loaded) {
@@ -389,7 +494,6 @@ sub end_numericalresponse {
     my $tag;
     my $safehole = new Safe::Hole;
     $safeeval->share_from('capa',['&caparesponse_capa_check_answer']);
-    $safehole->wrap(\&Apache::lonmaxima::maxima_check,$safeeval,'&maxima_check');
 
     if (scalar(@$tagstack)) { $tag=$$tagstack[-1]; }
     if ( $target eq 'grade' && &Apache::response::submitted() ) {
@@ -497,6 +601,7 @@ sub end_numericalresponse {
 		}
 	    }
 	}
+	&Apache::response::setup_prior_tries_hash(\&format_prior_response_numerical);
     } elsif ($target eq 'edit') {
 	$result.='</td></tr>'.&Apache::edit::end_table;
     } elsif ($target eq 'answer' || $target eq 'analyze') {
@@ -687,6 +792,22 @@ sub end_numericalresponse {
     return $result;
 }
 
+sub format_prior_response_numerical {
+    my ($mode,$answer) = @_;
+    if (ref($answer)) {
+	my $result = '<table class="LC_prior_numerical"><tr>';
+	foreach my $element (@{ $answer }) {
+	    $result.= '<td><span class="LC_prior_numerical">'.
+		&HTML::Entities::encode($element,'"<>&').'</span></td>';
+	}
+	$result.='</tr></table>';
+	return $result;
+    }
+    return '<span class="LC_prior_numerical">'.
+	    &HTML::Entities::encode($answer,'"<>&').'</span>';
+
+}
+
 sub check_for_answer_errors {
     my ($parstack,$safeeval) = @_;
     &add_in_tag_answer($parstack,$safeeval);
@@ -706,7 +827,8 @@ sub check_for_answer_errors {
     use Data::Dumper;
     &Apache::lonxml::debug("count dump is ".&Dumper(\%counts));
     my $expected_number_of_inputs = (keys(%counts))[0];
-    if ( $expected_number_of_inputs != scalar(@Apache::inputtags::inputlist)) {
+    if ( $expected_number_of_inputs > 0 
+	 && $expected_number_of_inputs != scalar(@Apache::inputtags::inputlist)) {
 	&Apache::lonxml::error(&mt("Expected [_1] input fields, but there were only [_2] seen.", 
 				   $expected_number_of_inputs,
 				   scalar(@Apache::inputtags::inputlist)));
@@ -906,6 +1028,12 @@ sub get_sigrange {
     return ($sig_ubound,$sig_lbound);
 }
 
+sub format_prior_response_string {
+    my ($mode,$answer) =@_;
+    return '<span class="LC_prior_string">'.
+	    &HTML::Entities::encode($answer,'"<>&').'</span>';
+}
+
 sub start_stringresponse {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
     my $result;
@@ -1083,6 +1211,8 @@ sub end_stringresponse {
 	}
     } elsif ($target eq 'edit') {
 	$result.='</td></tr>'.&Apache::edit::end_table;
+    } elsif ($target eq 'web' || $target eq 'tex') {
+	&Apache::response::setup_prior_tries_hash(\&format_prior_response_string);
     }
     if ($target eq 'grade' || $target eq 'web' || $target eq 'answer' || 
 	$target eq 'tex' || $target eq 'analyze') {
