@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # input  definitons
 #
-# $Id: inputtags.pm,v 1.212 2006/12/22 18:30:07 albertel Exp $
+# $Id: inputtags.pm,v 1.225 2007/05/21 23:09:57 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -70,6 +70,10 @@ BEGIN {
 #  %Apache::inputtags::answertxt    - <*response> tags store correct
 #                                     answer strings for display by <textline/>
 #                                     in this hash.
+#  %Apache::inputtags::submission_display
+#                                   - <*response> tags store improved display
+#                                     of submission strings for display by part
+#                                     end.
 
 sub initialize_inputtags {
     @Apache::inputtags::input=();
@@ -88,6 +92,7 @@ sub initialize_inputtags {
     @Apache::inputtags::importlist=();
     $Apache::inputtags::response_with_no_part=0;
     %Apache::inputtags::answertxt=();
+    %Apache::inputtags::submission_display=();
 }
 
 sub check_for_duplicate_ids {
@@ -292,7 +297,9 @@ sub start_textline {
 	    my $size = &Apache::lonxml::get_param('size',$parstack,$safeeval);
 	    my $maxlength;
 	    if ($size eq '') { $size=20; } else {
-		if ($size < 20) { $maxlength=$size; }
+		if ($size < 20) {
+		    $maxlength = ' maxlength="'.$size.'"';
+		}
 	    }
 	    my $oldresponse = $Apache::lonhomework::history{"resource.$partid.$id.submission"};
 	    &Apache::lonxml::debug("oldresponse $oldresponse is ".ref($oldresponse));
@@ -320,8 +327,8 @@ sub start_textline {
 		if ($Apache::inputtags::status[-1] eq 'CANNOT_ANSWER') {
 		    $name = "none";
 		}
-		$result.= '<input type="text" '.$readonly.' name="'.$name.'" value="'.
-		    $oldresponse.'" size="'.$size.'" maxlength="'.$maxlength.'" />';
+		$result.= '<input onkeydown="javascript:setSubmittedPart(\''.$partid.'\');" type="text" '.$readonly.' name="'.$name.'" value="'.
+		    $oldresponse.'" size="'.$size.'"'.$maxlength.' />';
 	    }
 	    if ($Apache::lonhomework::type eq 'exam'
 		&& &needs_exam_box($tagstack)) {
@@ -579,14 +586,14 @@ sub decideoutput {
     my $message='';
     my $button=0;
     my $previousmsg;
-    my $bgcolor='orange';
+    my $css_class='orange';
     my $added_computer_text=0;
-    my %possiblecolors =
-	( 'correct'         => '#aaffaa',
-	  'charged_try'     => '#ffaaaa',
-	  'not_charged_try' => '#ffffaa',
-	  'no_grade'        => '#ffffaa',
-	  'no_message'      => '#ffffff',
+    my %possible_class =
+	( 'correct'         => 'LC_answer_correct',
+	  'charged_try'     => 'LC_answer_charged_try',
+	  'not_charged_try' => 'LC_answer_not_charged_try',
+	  'no_grade'        => 'LC_answer_no_grade',
+	  'no_message'      => 'LC_no_message',
 	  );
 
     my $part = $Apache::inputtags::part;
@@ -600,14 +607,14 @@ sub decideoutput {
     if ($previous) { $previousmsg=&mt('You have entered that answer before'); }
     
     if ($solved =~ /^correct/) {
-        $bgcolor=$possiblecolors{'correct'};
+        $css_class=$possible_class{'correct'};
 	$message=&mt('You are correct.');
 	if ($awarded < 1 && $awarded > 0) {
 	    $message=&mt('You are partially correct.');
-	    $bgcolor=$possiblecolors{'not_charged_try'};
+	    $css_class=$possible_class{'not_charged_try'};
 	} elsif ($awarded < 1) {
 	    $message=&mt('Incorrect.');
-	    $bgcolor=$possiblecolors{'charged_try'};
+	    $css_class=$possible_class{'charged_try'};
 	}
 	if ($env{'request.filename'} =~ 
 	    m|/res/lib/templates/examupload.problem$|) {
@@ -621,9 +628,11 @@ sub decideoutput {
 		$message.= $computer;
 	    }
 	    $added_computer_text=1;
-	    unless ($env{'course.'.
-			     $env{'request.course.id'}.
-			     '.disable_receipt_display'} eq 'yes') { 
+	    my ($symb) = &Apache::lonnet::whichuser();
+	    if (($symb ne '') 
+		&&
+		($env{'course.'.$env{'request.course.id'}.
+			    '.disable_receipt_display'} ne 'yes')) { 
 		$message.=(($target eq 'web')?'<br />':' ').
 		    &mt('Your receipt is').' '.&Apache::lonnet::receipt($Apache::inputtags::part).
 		    (($target eq 'web')?&Apache::loncommon::help_open_topic('Receipt'):'');
@@ -637,13 +646,13 @@ sub decideoutput {
 	} else {
 	    $message = "<b>".&mt('You are excused from the problem.')."</b>";
 	}
-	$bgcolor=$possiblecolors{'charged_try'};
+	$css_class=$possible_class{'charged_try'};
 	$button=0;
 	$previousmsg='';
     } elsif ($award eq 'EXACT_ANS' || $award eq 'APPROX_ANS' ) {
 	if ($solved =~ /^incorrect/ || $solved eq '') {
 	    $message = &mt("Incorrect").".";
-	    $bgcolor=$possiblecolors{'charged_try'};
+	    $css_class=$possible_class{'charged_try'};
 	    $button=1;
 	} else {
 	    if ($target eq 'tex') {
@@ -660,105 +669,105 @@ sub decideoutput {
 		    'Your receipt is '.&Apache::lonnet::receipt($Apache::inputtags::part).
 		    (($target eq 'web')?&Apache::loncommon::help_open_topic('Receipt'):'');
 	    }
-	    $bgcolor=$possiblecolors{'correct'};
+	    $css_class=$possible_class{'correct'};
 	    $button=0;
 	    $previousmsg='';
 	}
     } elsif ($award eq 'NO_RESPONSE') {
 	$message = '';
-	$bgcolor=$possiblecolors{'no_feedback'};
+	$css_class=$possible_class{'no_feedback'};
 	$button=1;
     } elsif ($award eq 'EXTRA_ANSWER') {
 	$message = &mt('Some extra items were submitted.');
-	$bgcolor=$possiblecolors{'not_charged_try'};
+	$css_class=$possible_class{'not_charged_try'};
 	$button = 1;
     } elsif ($award eq 'MISSING_ANSWER') {
 	$message = &mt('Some items were not submitted.');
-	$bgcolor=$possiblecolors{'not_charged_try'};
+	$css_class=$possible_class{'not_charged_try'};
 	$button = 1;
     } elsif ($award eq 'ERROR') {
 	$message = &mt('An error occured while grading your answer.');
-	$bgcolor=$possiblecolors{'not_charged_try'};
+	$css_class=$possible_class{'not_charged_try'};
 	$button = 1;
     } elsif ($award eq 'TOO_LONG') {
 	$message = &mt("The submitted answer was too long.");
-	$bgcolor=$possiblecolors{'not_charged_try'};
+	$css_class=$possible_class{'not_charged_try'};
 	$button=1;
     } elsif ($award eq 'WANTED_NUMERIC') {
 	$message = &mt("This question expects a numeric answer.");
-	$bgcolor=$possiblecolors{'not_charged_try'};
+	$css_class=$possible_class{'not_charged_try'};
 	$button=1;
     } elsif ($award eq 'MISORDERED_RANK') {
 	$message = &mt('You have provided an invalid ranking');
 	if ($target ne 'tex') {
 	    $message.=', '.&mt('please refer to').' '.&Apache::loncommon::help_open_topic('Ranking_Problems','help on ranking problems');
 	}
-	$bgcolor=$possiblecolors{'not_charged_try'};
+	$css_class=$possible_class{'not_charged_try'};
 	$button=1;
     } elsif ($award eq 'INVALID_FILETYPE') {
 	$message = &mt('Submission won\'t be graded. The type of file submitted is not allowed.');
-	$bgcolor=$possiblecolors{'not_charged_try'};
+	$css_class=$possible_class{'not_charged_try'};
 	$button=1;
     } elsif ($award eq 'SIG_FAIL') {
 	my ($used,$min,$max)=split(':',$awardmsg);
 	my $word = ($used < $min) ? 'more' : 'fewer';
 	$message = &mt("Submission not graded.  Use $word digits.",$used);
-	$bgcolor=$possiblecolors{'not_charged_try'};
+	$css_class=$possible_class{'not_charged_try'};
 	$button=1;
     } elsif ($award eq 'UNIT_INVALID_INSTRUCTOR') {
 	$message = &mt('Error in instructor specifed unit. This error has been reported to the instructor.', $awardmsg);
 	if ($target ne 'tex') {$message.=&Apache::loncommon::help_open_topic('Physical_Units');} 
-	$bgcolor=$possiblecolors{'not_charged_try'};
+	$css_class=$possible_class{'not_charged_try'};
 	$button=1;
     } elsif ($award eq 'UNIT_INVALID_STUDENT') {
 	$message = &mt('Unable to interpret units. Computer reads units as "[_1]".',&markup_unit($awardmsg,$target));
 	if ($target ne 'tex') {$message.=&Apache::loncommon::help_open_topic('Physical_Units');} 
-	$bgcolor=$possiblecolors{'not_charged_try'};
+	$css_class=$possible_class{'not_charged_try'};
 	$button=1;
     } elsif ($award eq 'UNIT_FAIL' || $award eq 'UNIT_IRRECONCIBLE') {
 	$message = &mt('Incompatible units. No conversion found between "[_1]" and the required units.',&markup_unit($awardmsg,$target));
 	if ($target ne 'tex') {$message.=&Apache::loncommon::help_open_topic('Physical_Units');} 
-	$bgcolor=$possiblecolors{'not_charged_try'};
+	$css_class=$possible_class{'not_charged_try'};
 	$button=1;
     } elsif ($award eq 'UNIT_NOTNEEDED') {
 	$message = &mt('Only a number required. Computer reads units of "[_1]".',&markup_unit($awardmsg,$target));
-	$bgcolor=$possiblecolors{'not_charged_try'};
+	$css_class=$possible_class{'not_charged_try'};
 	$button=1;
     } elsif ($award eq 'NO_UNIT') {
 	$message = &mt("Units required").'.';
 	if ($target ne 'tex') {$message.=&Apache::loncommon::help_open_topic('Physical_Units')};
-	$bgcolor=$possiblecolors{'not_charged_try'};
+	$css_class=$possible_class{'not_charged_try'};
 	$button=1;
     } elsif ($award eq 'COMMA_FAIL') {
 	$message = &mt("Proper comma separation is required").'.';
-	$bgcolor=$possiblecolors{'not_charged_try'};
+	$css_class=$possible_class{'not_charged_try'};
 	$button=1;
     } elsif ($award eq 'BAD_FORMULA') {
 	$message = &mt("Unable to understand formula");
-	$bgcolor=$possiblecolors{'not_charged_try'};
+	$css_class=$possible_class{'not_charged_try'};
 	$button=1;
     } elsif ($award eq 'INCORRECT') {
 	$message = &mt("Incorrect").'.';
-	$bgcolor=$possiblecolors{'charged_try'};
+	$css_class=$possible_class{'charged_try'};
 	$button=1;
     } elsif ($award eq 'SUBMITTED') {
 	$message = &mt("Your submission has been recorded.");
-	$bgcolor=$possiblecolors{'no_grade'};
+	$css_class=$possible_class{'no_grade'};
 	$button=1;
     } elsif ($award eq 'DRAFT') {
 	$message = &mt("A draft copy has been saved.");
-	$bgcolor=$possiblecolors{'not_charged_try'};
+	$css_class=$possible_class{'not_charged_try'};
 	$button=1;
     } elsif ($award eq 'ASSIGNED_SCORE') {
 	$message = &mt("A score has been assigned.");
-	$bgcolor=$possiblecolors{'correct'};
+	$css_class=$possible_class{'correct'};
 	$button=0;
     } elsif ($award eq '') {
 	if ($handgrade && $Apache::inputtags::status[-1] eq 'SHOW_ANSWER') {
 	    $message = &mt("Nothing submitted.");
-	    $bgcolor=$possiblecolors{'charged_try'};
+	    $css_class=$possible_class{'charged_try'};
 	} else {
-	    $bgcolor=$possiblecolors{'not_charged_try'};
+	    $css_class=$possible_class{'not_charged_try'};
 	}
 	$button=1;
     } else {
@@ -782,7 +791,7 @@ sub decideoutput {
     if (lc($Apache::lonhomework::problemstatus) eq 'no'  && 
 	$Apache::inputtags::status[-1] ne 'SHOW_ANSWER') {
 	$message = &mt("Answer Submitted: Your final submission will be graded after the due date.");
-	$bgcolor=$possiblecolors{'no_grade'};
+	$css_class=$possible_class{'no_grade'};
 	$button=1;
     }
     if ($Apache::inputtags::status[-1] eq 'SHOW_ANSWER' && 
@@ -790,7 +799,7 @@ sub decideoutput {
 	$message.= $computer;
 	$added_computer_text=1;
     }
-    return ($button,$bgcolor,$message,$previousmsg);
+    return ($button,$css_class,$message,$previousmsg);
 }
 
 sub markup_unit {
@@ -948,6 +957,42 @@ sub setgradedata {
     }
 }
 
+sub find_which_previous {
+    my ($version) = @_;
+    my $part = $Apache::inputtags::part;
+    my (@previous_version);
+    foreach my $resp (@Apache::inputtags::response) {
+	my $key = "$version:resource.$part.$resp.submission";
+	my $submission = $Apache::lonhomework::history{$key};
+	my %previous = &Apache::response::check_for_previous($submission,
+							     $part,$resp,
+							     $version);
+	push(@previous_version,$previous{'version'});
+    }
+    return &previous_match(\@previous_version,
+			   scalar(@Apache::inputtags::response));
+}
+
+sub previous_match {
+    my ($previous_array,$count) = @_;
+    my $match = 0;
+    my @matches;
+    foreach my $versionar (@$previous_array) {
+	foreach my $version (@$versionar) {
+	    $matches[$version]++;
+	}
+    }
+    my $which=0;
+    foreach my $elem (@matches) {
+	if ($elem eq $count) {
+	    $match=1;
+	    last;
+	}
+	$which++;
+    }
+    return ($match,$which);
+}
+
 sub grade {
     my ($target) = @_;
     my $id = $Apache::inputtags::part;
@@ -966,14 +1011,10 @@ sub grade {
 	my ($finalaward,$msg) = &finalizeawards(\@awards,\@msgs);
 	my $previously_used;
 	if ( $#Apache::inputtags::previous eq $#awards ) {
-	    my $match=0;
-	    my @matches;
-	    foreach my $versionar (@Apache::inputtags::previous_version) {
-		foreach my $version (@$versionar) {
-		    $matches[$version]++;
-		}
-	    }
-	    foreach my $elem (@matches) {if ($elem eq ($#awards+1)) {$match=1;}}
+	    my ($match) =
+		&previous_match(\@Apache::inputtags::previous_version,
+				scalar(@Apache::inputtags::response));
+	    
 	    if ($match) {
 		$previously_used = 'PREVIOUSLY_LAST';
 		foreach my $value (@Apache::inputtags::previous) {
@@ -990,10 +1031,83 @@ sub grade {
     return '';
 }
 
+sub get_grade_messages {
+    my ($id,$prefix,$target,$status) = @_;
+
+    my ($message,$latemessage,$trystr,$previousmsg);
+    my $showbutton = 1;
+
+    my $award = $Apache::lonhomework::history{"$prefix.award"};
+    my $awarded = $Apache::lonhomework::history{"$prefix.awarded"};
+    my $solved = $Apache::lonhomework::history{"$prefix.solved"};
+    my $previous = $Apache::lonhomework::history{"$prefix.previous"};
+    my $awardmsg = $Apache::lonhomework::history{"$prefix.awardmsg"};
+    &Apache::lonxml::debug("Found Award |$award|$solved|$awardmsg");
+    if ( $award ne '' || $solved ne '' || $status eq 'SHOW_ANSWER') {
+	&Apache::lonxml::debug('Getting message');
+	($showbutton,my $css_class,$message,$previousmsg) =
+	    &decideoutput($award,$awarded,$awardmsg,$solved,$previous,
+			  $target);
+	if ($target eq 'tex') {
+	    $message='\vskip 2 mm '.$message.' ';
+	} else {
+	    $message="<td class=\"$css_class\">$message</td>";
+	    if ($previousmsg) {
+		$previousmsg="<td class=\"LC_answer_previous\">$previousmsg</td>";
+	    }
+	}
+    }
+    my $tries = $Apache::lonhomework::history{"$prefix.tries"};
+    my $maxtries = &Apache::lonnet::EXT("resource.$id.maxtries");
+    &Apache::lonxml::debug("got maxtries of :$maxtries:");
+    #if tries are set to negative turn off the Tries/Button and messages
+    if (defined($maxtries) && $maxtries < 0) { return ''; }
+    if ( $tries eq '' ) { $tries = '0'; }
+    if ( $maxtries eq '' ) { $maxtries = '2'; } 
+    if ( $maxtries eq 'con_lost' ) { $maxtries = '0'; } 
+    my $tries_text=&mt('Tries');
+    if ( $Apache::lonhomework::type eq 'survey' ||
+	 $Apache::lonhomework::parsing_a_task) {
+	$tries_text=&mt('Submissions');
+    }
+
+    if ($showbutton) {
+	if ($target eq 'tex') {
+	    if ($env{'request.state'} ne "construct"
+		&& $Apache::lonhomework::type ne 'exam'
+		&& $env{'form.suppress_tries'} ne 'yes') {
+		$trystr = ' {\vskip 1 mm \small \textit{'.$tries_text.'} '.
+		    $tries.'/'.$maxtries.'} \vskip 2 mm ';
+	    } else {
+		$trystr = '\vskip 0 mm ';
+	    }
+	} else {
+	    $trystr = "<td><nobr>".$tries_text." $tries";
+	    if ($Apache::lonhomework::parsing_a_task) {
+	    } elsif($env{'request.state'} ne 'construct') {
+		$trystr.="/$maxtries";
+	    } else {
+		if (defined($Apache::inputtags::params{'maxtries'})) {
+		    $trystr.="/".$Apache::inputtags::params{'maxtries'};
+		}
+	    }
+	    $trystr.="</nobr></td>";
+	}
+    }
+
+    if ($Apache::lonhomework::history{"$prefix.afterduedate"}) {
+	#last submissions was after due date
+	$latemessage=&mt(' The last submission was after the Due Date ');;
+	if ($target eq 'web') {
+	    $latemessage='<td class="LC_answer_late">'.$latemessage.'</td>';
+	}
+    }
+    return ($previousmsg,$latemessage,$message,$trystr,$showbutton);
+}
+
 sub gradestatus {
-    my ($id,$target) = @_;
+    my ($id,$target,$no_previous) = @_;
     my $showbutton = 1;
-    my $bgcolor = '';
     my $message = '';
     my $latemessage = '';
     my $trystr='';
@@ -1007,72 +1121,22 @@ sub gradestatus {
 	 && $status ne 'INVALID_ACCESS' 
 	 && $status ne 'NEEDS_CHECKIN' 
 	 && $status ne 'NOT_IN_A_SLOT') {  
-	my $award = $Apache::lonhomework::history{"resource.$id.award"};
-	my $awarded = $Apache::lonhomework::history{"resource.$id.awarded"};
-	my $solved = $Apache::lonhomework::history{"resource.$id.solved"};
-	my $previous = $Apache::lonhomework::history{"resource.$id.previous"};
-	my $awardmsg = $Apache::lonhomework::history{"resource.$id.awardmsg"};
-	&Apache::lonxml::debug("Found Award |$award|$solved|$awardmsg");
-	if ( $award ne '' || $solved ne '' || $status eq 'SHOW_ANSWER') {
-	    &Apache::lonxml::debug('Getting message');
-	    ($showbutton,$bgcolor,$message,$previousmsg) =
-		&decideoutput($award,$awarded,$awardmsg,$solved,$previous,
-			      $target);
-	    if ($target eq 'tex') {
-		$message='\vskip 2 mm '.$message.' ';
-	    } else {
-		$message="<td bgcolor=\"$bgcolor\">$message</td>";
-		if ($previousmsg) {
-		    $previousmsg="<td bgcolor=\"#aaaaff\">$previousmsg</td>";
-		}
-	    }
+
+	($previousmsg,$latemessage,$message,$trystr) =
+	    &get_grade_messages($id,"resource.$id",$target,$status,
+				$showbutton);
+	if ( $status eq 'SHOW_ANSWER' || $status eq 'CANNOT_ANSWER') {
+	    $showbutton = 0;
 	}
-	my $tries = $Apache::lonhomework::history{"resource.$id.tries"};
-	my $maxtries = &Apache::lonnet::EXT("resource.$id.maxtries");
-	&Apache::lonxml::debug("got maxtries of :$maxtries:");
-	#if tries are set to negative turn off the Tries/Button and messages
-	if (defined($maxtries) && $maxtries < 0) { return ''; }
-	if ( $tries eq '' ) { $tries = '0'; }
-	if ( $maxtries eq '' ) { $maxtries = '2'; } 
-	if ( $maxtries eq 'con_lost' ) { $maxtries = '0'; } 
-	my $tries_text=&mt('Tries');
-	if ( $Apache::lonhomework::type eq 'survey' ||
-	     $Apache::lonhomework::parsing_a_task) {
-	    $tries_text=&mt('Submissions');
+	if ( $status eq 'SHOW_ANSWER') {
+	    undef($previousmsg);
 	}
-	if ( $showbutton ) {
-	    if ($target eq 'tex') {
-		if ($env{'request.state'} ne "construct" && $Apache::lonhomework::type ne 'exam' && $env{'form.suppress_tries'} ne 'yes') {
-		    $trystr = ' {\vskip 1 mm \small \textit{'.$tries_text.'} '.$tries.'/'.$maxtries.'} \vskip 2 mm ';
-		} else {
-		    $trystr = '\vskip 0 mm ';
-		}
-	    } else {
-		$trystr = "<td><nobr>".$tries_text." $tries";
-		if ($Apache::lonhomework::parsing_a_task) {
-		} elsif($env{'request.state'} ne 'construct') {
-		    $trystr.="/$maxtries";
-		} else {
-		    if (defined($Apache::inputtags::params{'maxtries'})) {
-			$trystr.="/".$Apache::inputtags::params{'maxtries'};
-		    }
-		}
-		$trystr.="</nobr></td>";
-	    }
-	}
-	if ( $status eq 'SHOW_ANSWER' || $status eq 'CANNOT_ANSWER') {$showbutton = 0;}
 	if ( $showbutton ) { 
 	    if ($target ne 'tex') {
-		$button = '<input type="submit" name="submit_'.$id.'" value="'.&mt('Submit Answer').'" />';
-	    }
-	}
-	if ($Apache::lonhomework::history{"resource.$id.afterduedate"}) {
-	    #last submissions was after due date
-	    $latemessage=&mt(' The last submission was after the Due Date ');;
-	    if ($target eq 'web') {
-		$latemessage='<td bgcolor="#ffaaaa">'.$latemessage.'</td>';
+		$button = '<input onsubmit="javascript:setSubmittedPart(\''.$id.'\')" type="submit" name="submit_'.$id.'" value="'.&mt('Submit Answer').'" />';
 	    }
 	}
+
     }
     my $output= $previousmsg.$latemessage.$message.$trystr;
     if ($output =~ /^\s*$/) {
@@ -1081,10 +1145,108 @@ sub gradestatus {
 	if ($target eq 'tex') {
 	    return $button.' \vskip 0 mm '.$output.' ';
 	} else {
-	    return '<table><tr><td>'.$button.'</td>'.$output.'</tr></table>';
+	    $output =
+		'<table><tr><td>'.$button.'</td>'.$output;
+	    if (!$no_previous) {
+		$output.='<td>'.&previous_tries($id,$target).'</td>';
+	    }
+	    $output.= '</tr></table>';
+	    return $output;
 	}
     }
 }
+
+sub previous_tries {
+    my ($id,$target) = @_;
+    my $output;
+    my $status = $Apache::inputtags::status['-1'];
+
+    my $count;
+    my %count_lookup;
+
+    foreach my $i (1..$Apache::lonhomework::history{'version'}) {
+	my $prefix = $i.":resource.$id";
+
+	next if (!exists($Apache::lonhomework::history{"$prefix.award"}));
+	$count++;
+	$count_lookup{$i} = $count;
+	
+	my ($previousmsg,$latemessage,$message,$trystr);
+
+	($previousmsg,$latemessage,$message,$trystr) =
+	    &get_grade_messages($id,"$prefix",$target,$status);
+
+	if ($previousmsg ne '') {
+	    my ($match,$which) = &find_which_previous($i);
+	    $message=$previousmsg;
+	    my $previous = $count_lookup{$which};
+	    $message =~ s{(</td>)}{ as submission # $previous $1};
+	} elsif ($Apache::lonhomework::history{"$prefix.tries"}) {
+	    if (!(lc($Apache::lonhomework::problemstatus) eq 'no'
+		  && $Apache::inputtags::status[-1] ne 'SHOW_ANSWER')
+		&& $Apache::lonhomework::history{"$prefix.solved"} =~/^correct/
+		) {
+		
+		$message =~ s{(<td.*?>)(.*?)(</td>)}
+		             {$1 <strong>Correct</strong>. $3}s;
+	    }
+	    my $trystr = "(Try ".
+		$Apache::lonhomework::history{"$prefix.tries"}.')';
+	    $message =~ s{(</td>)}{ $trystr $1};
+	}
+	my ($class) = ($message =~ m{<td.*class="([^"]*)"}); #"
+	$message =~ s{(<td.*?>)}{<td>};
+	
+
+	$output.='<tr class="'.$class.'">';
+	$output.='<td align="center">'.$count.'</td>';
+	$output.=$message;
+
+	foreach my $resid (@Apache::inputtags::response) {
+	    my $prefix = $prefix.".$resid";
+	    if (exists($Apache::lonhomework::history{"$prefix.submission"})) {
+		my $submission =
+		    $Apache::inputtags::submission_display{"$prefix.submission"};
+		if (!defined($submission)) {
+		    $submission = 
+			$Apache::lonhomework::history{"$prefix.submission"};
+		}
+		$output.='<td>'.$submission.'</td>';
+	    } else {
+		$output.='<td></td>';
+	    }
+	}
+	$output.=&Apache::loncommon::end_data_table_row()."\n";
+    }
+    return if ($output eq '');
+    my $headers = 
+	'<tr>'.'<th>'.&mt('Submission #').'</th><th>'.&mt('Try').
+	'</th><th colspan="'.scalar(@Apache::inputtags::response).'">'.
+	&mt('Submitted Answer').'</th>';
+    $output ='<table class="LC_prior_tries">'.$headers.$output.'</table>';
+    #return $output;
+    $output=~s/\\/\\\\/g;
+    $output=~s/\'/\\\'/g;
+    $output=~s/\s+/ /g;
+    my $windowopen=&Apache::lonhtmlcommon::javascript_docopen();
+    my $start_page =
+	&Apache::loncommon::start_page('Previous Tries', undef,
+				       {'only_body' => 1,
+					'bgcolor'   => '#FFFFFF',
+					'js_ready'  => 1,});
+    my $end_page =
+	&Apache::loncommon::end_page({'js_ready' => 1,});
+    
+    my $result ="<script type=\"text/javascript\">
+// <![CDATA[
+    function LONCAPA_previous_tries_$Apache::lonxml::curdepth() {newWindow=open('','new_W','width=500,height=500,scrollbars=1,resizable=yes');newWindow.$windowopen;newWindow.document.writeln('$start_page $output $end_page');newWindow.document.close();newWindow.focus()}
+// ]]>
+</script><a href=\"javascript:LONCAPA_previous_tries_$Apache::lonxml::curdepth();void(0);\">".&mt("Previous Tries")."</a><br />";
+    #use Data::Dumper;
+    #&Apache::lonnet::logthis(&Dumper(\%Apache::inputtags::submission_display));
+    return $result;
+}
+
 1;
 __END__
  
