@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Full matching style response
 #
-# $Id: matchresponse.pm,v 1.59 2006/04/04 22:30:52 foxr Exp $
+# $Id: matchresponse.pm,v 1.64 2007/04/17 23:25:09 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -163,6 +163,7 @@ sub end_itemgroup {
 	if ($direction eq 'horizontal') { $table .='</tr>';}
 	$table.='</table>';
 	$Apache::matchresponse::itemtable{'display'}=$table;
+	$Apache::lonxml::post_evaluate=0;
     } elsif ($target eq 'tex') {
 	my $table=' \begin{description}\setlength{\leftmargin}{2em}\setlength{\labelwidth}{1em}\setlength{\itemsep}{0.5pt plus1pt minus2pt}\setlength{\listparindent}{0em} ';
 	my $i=0;
@@ -175,6 +176,7 @@ sub end_itemgroup {
 	$table.=' \end{description}  \strut ';
 	if ($Apache::lonhomework::type eq 'exam') {$table.='\vskip -13 mm \strut ';}
 	$Apache::matchresponse::itemtable{'display'}=$table;
+	$Apache::lonxml::post_evaluate=0;
     }
     return $result;
 }
@@ -263,6 +265,7 @@ sub end_foilgroup {
 						   $safeeval,'-2');
 	if ($target eq 'web' || $target eq 'tex') {
 	    $result=&displayfoils($target,$max,$randomize);
+	    $Apache::lonxml::post_evaluate=0;
 	} elsif ($target eq 'answer' ) {
 	    $result=&displayanswers($max,$randomize);
 	} elsif ( $target eq 'grade') {
@@ -412,6 +415,24 @@ sub grade_response {
     }
 }
 
+sub format_prior_answer {
+    my ($mode,$answer,$other_data) = @_;
+    my %answer      =&Apache::lonnet::str2hash($answer);
+    my $foil_order  =$other_data->[0];
+    my %grading     =&Apache::lonnet::str2hash($other_data->[1]);
+    my @items       =&Apache::lonnet::str2array($other_data->[2]);
+    my $output;
+    
+    foreach my $name (@{ $foil_order }) {
+	my $item=shift(@items);
+	$output .= '<tr><td>'.$item.'</td></tr>';
+    }
+    return if (!defined($output));
+
+    $output = '<table class="LC_prior_match">'.$output.'</table>';
+    return $output;
+}
+
 sub itemdisplay {
     my ($location)=@_;
     if ($location eq 'top' &&
@@ -423,8 +444,11 @@ sub itemdisplay {
     }
     return undef;
 }
+
 sub displayfoils {
     my ($target,$max,$randomize)=@_;
+    my ($tabsize, $lefttabsize, $righttabsize);
+
     my $result;
     my $question;
     my (@whichfoils)=&Apache::response::whichorder(&getfoilcounts($max),
@@ -484,11 +508,31 @@ sub displayfoils {
 		}
 	    }
 	    if ($target ne 'tex' && $Apache::lonhomework::type ne 'exam') {
-	        $optionlist='<select name="HWVAL_'.
+	        $optionlist='<select onchange="javascript:setSubmittedPart(\''.
+		  $part.'\');" name="HWVAL_'.
 		    $Apache::inputtags::response[-1].':'.$temp.'">'.
 		        $optionlist."</select>\n";
 	    }
 	    my $text=$Apache::response::foilgroup{$name.'.text'};
+	    #
+            #  Factor out the tex computations of the left/right 1/2 minipage
+	    #  widths for left or right positioning.  This allows us
+	    #  to, if necessary constrain the bubble widths:
+	    #
+	    if ($target eq 'tex'   &&
+		(&itemdisplay('left') || &itemdisplay('right'))) {
+		$tabsize=&Apache::londefdef::recalc($env{'form.textwidth'});
+		($lefttabsize,$righttabsize)=(0,0);
+		if ($Apache::matchresponse::TeXitemgroupwidth ne '') {
+		    $Apache::matchresponse::TeXitemgroupwidth=~/(\d*.?\d*)/;
+		    $lefttabsize=$tabsize*$1/100;	
+		    $righttabsize=0.95*($tabsize-$lefttabsize);
+		} else {
+		    $tabsize=~/(\d+\.?\d*)/;
+		    $lefttabsize=$1/2.1;
+		    $righttabsize=0.95*($1-$lefttabsize);
+		}
+	    }
 	    if ($target ne 'tex') {
 		if ($Apache::lonhomework::type ne 'exam') {
 		    $question.="<br />\n".$optionlist.$text;
@@ -500,11 +544,22 @@ sub displayfoils {
 		    $question.=&Apache::optionresponse::webbubbles(\@used_letters,\@blank,$temp,$last_letter);
 		}
 	    } else {		
+		# Note that if left or right positioned, we must
+		# confine the bubbles to righttabsize:
+		#
 		if ($Apache::lonhomework::type eq 'exam') {
 		    $question.=' '.$optionlist.$text."\n";
 		    my @emptyItems = ();
 		    for (my $i=0;$i<=$#used_letters;$i++) {push @emptyItems, ' ';}
-		    $question.='\vskip -1 mm\noindent\begin{enumerate}\item[\textbf{'.$internal_counter.'}.]'.&Apache::optionresponse::bubbles(\@used_letters,\@emptyItems).'\end{enumerate} \vskip -8 mm \strut ';
+		    $question.='\vskip -1 mm\noindent\begin{list}{}{\setlength{\listparindent}{0mm}\setlength{\leftmargin}{2mm}}'
+			.'\item \hskip -3mm \textbf{'.$internal_counter.'}';
+		    if (&itemdisplay('left') || &itemdisplay('right')) {
+			$question .= &Apache::optionresponse::bubbles(\@used_letters,\@emptyItems, "", $righttabsize);
+		    }
+		    else {
+			$question .= &Apache::optionresponse::bubbles(\@used_letters,\@emptyItems);
+		    }
+		    $question .= '\end{list} \vskip -8 mm \strut ';
 		    $internal_counter++;
 	        } else {
 		    $question.=' '.$optionlist.$text.'\strut\\\\\strut '."\n";
@@ -524,17 +579,6 @@ sub displayfoils {
 	    $result='<table><tr><td valign="top">'.$question.
 		'</td><td valign="top">'.$result.'</td></tr></table>';
 	} else {
-	    my $tabsize=&Apache::londefdef::recalc($env{'form.textwidth'});
-	    my ($lefttabsize,$righttabsize)=(0,0);
-	    if ($Apache::matchresponse::TeXitemgroupwidth ne '') {
-		$Apache::matchresponse::TeXitemgroupwidth=~/(\d*.?\d*)/;
-		$lefttabsize=$tabsize*$1/100;	
-		$righttabsize=0.95*($tabsize-$lefttabsize);
-	    } else {
-		$tabsize=~/(\d+\.?\d*)/;
-		$lefttabsize=$1/2.1;
-		$righttabsize=0.95*($1-$lefttabsize);
-	    }
 	    $lefttabsize.=' mm ';
 	    $righttabsize.=' mm ';
 	    $result='\setlength{\tabcolsep}{1 mm}\begin{tabular}{p{'.$righttabsize.'}p{'.$lefttabsize.'}}\begin{minipage}{'.$righttabsize.'}'.$question.'\end{minipage}&\begin{minipage}{'.$lefttabsize.'}'.$result.'\end{minipage}\end{tabular}';
@@ -546,22 +590,17 @@ sub displayfoils {
 	    $result='<table><tr><td valign="top">'.$result.
 		'</td><td valign="top">'.$question.'</td></tr></table>';
 	} else {
-	    my $tabsize=&Apache::londefdef::recalc($env{'form.textwidth'});
-	    my ($lefttabsize,$righttabsize)=(0,0);
-	    if ($Apache::matchresponse::TeXitemgroupwidth ne '') {
-		$Apache::matchresponse::TeXitemgroupwidth=~/(\d*.?\d*)/;
-		$lefttabsize=$tabsize*$1/100;	
-		$righttabsize=0.95*($tabsize-$lefttabsize);
-	    } else {
-		$tabsize=~/(\d+\.?\d*)/;
-		$lefttabsize=$1/2.1;
-		$righttabsize=0.95*($1-$lefttabsize);
-	    }
 	    $lefttabsize.=' mm ';
 	    $righttabsize.=' mm ';
 	    $result='\setlength{\tabcolsep}{1 mm}\begin{tabular}{p{'.$lefttabsize.'}p{'.$righttabsize.'}}\begin{minipage}{'.$lefttabsize.'}'.$result.'\end{minipage}&\begin{minipage}{'.$righttabsize.'}'.$question.'\end{minipage}\end{tabular}';
 	}
     }
+    if ($target eq 'web') {
+	&Apache::response::setup_prior_tries_hash(\&format_prior_answer,
+						  [\@whichfoils,
+						   'submissiongrading',
+						   'submissionitems']);
+    }
     if ($target ne 'tex') {$result.="<br />";} else {$result.=' \\\\ ';}
     return $result;
 }
