@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # definition of tags that give a structure to a document
 #
-# $Id: structuretags.pm,v 1.372 2006/12/11 01:07:07 albertel Exp $
+# $Id: structuretags.pm,v 1.377 2007/05/23 22:36:21 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -88,6 +88,14 @@ sub page_start {
 					   $parstack,$parser,$safeeval);
     }
 
+    $extra_head.= '
+<script type="text/javascript">
+function setSubmittedPart (part) {
+   this.document.lonhomework.submitted.value="part_"+part;
+}
+</script>
+';
+
     my %body_args;
     if (defined($found{'html'})) {
 	$body_args{'skip_phases'}{'head'}=1;
@@ -213,7 +221,8 @@ sub setup_rndseed {
 	    }
 	    $env{'form.rndseed'}=$rndseed;
 	}
-	if ($env{'form.resetdata'} eq &mt('New Problem Variation') ||
+	if ( ($env{'form.resetdata'} eq &mt('New Problem Variation')
+	      && $env{'form.submitted'} eq 'yes')  ||
 	    $env{'form.newrandomization'} eq &mt('New Randomization')) {
 	    srand(time);
 	    $rndseed=int(rand(2100000000));
@@ -276,9 +285,7 @@ sub option {
 sub problem_web_to_edit_header {
     my ($rndseed)=@_;
     my $result.='<input type="hidden" name="problemmode" value="'.&mt('View').'" />';
-    if (!$Apache::lonhomework::parsing_a_task) {
-	$result .= '<input type="submit" name="problemmode" accesskey="e" value="'.&mt('Edit').'" />';
-    }
+    $result .= '<input type="submit" name="problemmode" accesskey="e" value="'.&mt('Edit').'" />';
     $result .= '<input type="submit" name="problemmode" accesskey="x" value="'.&mt('EditXML').'" />
              <input type="submit" name="newrandomization" accesskey="a" value="'.&mt('New Randomization').'" />
              <input type="submit" name="resetdata" accesskey="r" value="'.&mt('Reset Submissions').'" />
@@ -337,6 +344,20 @@ Feedback Mode:
 	     '.'.&Apache::loncommon::help_open_topic("Analyze_Problem",
 						     '',undef,undef,300).
 						     '<hr />';
+    } elsif ($Apache::lonhomework::parsing_a_task) {
+	$result.="
+<nobr>
+Problem Status:
+<select name='problemstate'>
+  <option value=''></option>
+  ".&option('CLOSED'               ,'problemstate').&mt("Closed")."</option>
+  ".&option('CAN_ANSWER'           ,'problemstate').&mt("Answerable")."</option>
+  ".&option('WEB_GRADE'            ,'problemstate').&mt("Criteria Grading")."</option>
+  ".&option('SHOW_ANSWER'          ,'problemstate').&mt("Show Feedback")."</option>
+</select>
+</nobr>
+<input type='submit' name='changeproblemmode' value='".&mt("Change")."' />
+<hr />";
     }
     return $result;
 }
@@ -360,7 +381,8 @@ sub initialize_storage {
 	
 	my $namespace = $symb || $env{'request.uri'};
 	if ($env{'form.resetdata'} eq &mt('Reset Submissions') ||
-	    $env{'form.resetdata'} eq &mt('New Problem Variation') ||
+	    ($env{'form.resetdata'} eq &mt('New Problem Variation')
+	     && $env{'form.submitted'} eq 'yes') ||
 	    $env{'form.newrandomization'} eq &mt('New Randomization')) {
 	    &Apache::lonnet::tmpreset($namespace,'',$domain,$name);
 	    &Apache::lonxml::debug("Attempt reset");
@@ -731,7 +753,8 @@ sub start_problem {
 	    my $bodytext=&Apache::lonxml::get_all_text("/problem",$parser,
 						       $style);
 	    if ($target eq 'web') {
-		$result .= &Apache::bridgetask::proctor_validation_screen();
+		$result .= 
+		    &Apache::bridgetask::proctor_validation_screen($slot);
 	    } elsif ($target eq 'grade') {
 		&Apache::bridgetask::proctor_check_auth($slot_name,$slot,
 							'problem');
@@ -769,7 +792,6 @@ sub start_problem {
 	$result.=$temp;
     } elsif ($target eq 'modified') {
 	$result=$token->[4];
-	$result.=&Apache::edit::handle_insert();
     } else {
 	# page_start returned a starting result, delete it if we don't need it
 	$result = '';
@@ -787,7 +809,6 @@ sub end_problem {
     }
 
     if ($target eq 'tex') {
-
 	# Figure out the front matter and replace the
 	# INSERTTEXFRONTMATTERHERE in result with it.  note that we do
 	# this in end_problem because whether or not we display due
@@ -947,7 +968,6 @@ sub end_problem {
 	$result .= &problem_edit_footer();
     } elsif ($target eq 'modified') {
 	 $result .= $token->[2];
-	 $result.=&Apache::edit::handle_insertafter($token->[1]);
     }
 
     if ($env{'request.state'} eq 'construct' && $target eq 'web') {
@@ -976,7 +996,6 @@ sub start_library {
 	$result.=$temp;
     } elsif ($target eq 'modified') {
 	$result=$token->[4];
-	$result.=&Apache::edit::handle_insert();
     } elsif (($target eq 'web' || $target eq 'webgrade')
 	     && ($#$tagstack eq 0 && $$tagstack[0] eq 'library')
 	     && $env{'request.state'} eq "construct" ) {
@@ -1423,7 +1442,6 @@ sub start_part {
 	    #limiting ids to only letters numbers, and space
 	    $token->[2]->{'id'}=~s/[^A-Za-z0-9 ]//gs;
 	    $result = &Apache::edit::rebuild_tag($token);
-	    $result.=&Apache::edit::handle_insert();
 	}
     }
     return $result;
@@ -1461,7 +1479,6 @@ sub end_part {
 	$result.=&Apache::edit::end_table();
     } elsif ($target eq 'modified') {
 	 $result .= $token->[2];
-	 $result.=&Apache::edit::handle_insertafter($token->[1]);
     }
     pop @Apache::inputtags::status;
     $Apache::inputtags::part='';
@@ -1630,7 +1647,8 @@ sub start_endouttext {
     if ($target eq "edit" ) { $result="</td></tr>".&Apache::edit::end_table()."\n"; }
     if ($target eq "modified") {
 	$result='<endouttext />'.
-	    &Apache::edit::handle_insertafter('startouttext'); }
+	    &Apache::edit::handle_insertafter('startouttext');
+    }
     return $result;
 }
 
