@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Create a course
 #
-# $Id: loncreatecourse.pm,v 1.99.2.1 2006/12/11 21:47:39 albertel Exp $
+# $Id: loncreatecourse.pm,v 1.101 2007/03/03 01:40:28 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -44,13 +44,12 @@ use LONCAPA;
 
 sub print_course_creation_page {
     my $r=shift;
-    my $crstype = 'Course';
-#    my $crstype = 'Group';
-#    if ($env{'form.phase'} eq 'courseone') {
-#        $crstype = 'Course';
-#    }
+    my $crstype = 'Group';
+    if ($env{'form.phase'} eq 'courseone') {
+        $crstype = 'Course';
+    }
     my $defdom=$env{'request.role.domain'};
-    my %host_servers = &Apache::loncommon::get_library_servers($defdom);
+    my %host_servers = &Apache::lonnet::get_servers($defdom,'library');
     my $course_home = '<select name="course_home" size="1">'."\n";
     foreach my $server (sort(keys(%host_servers))) {
         $course_home .= qq{<option value="$server"};
@@ -663,8 +662,8 @@ sub create_course {
 	return;
     }
     # Check the proposed home server for the course
-    my %host_servers = &Apache::loncommon::get_library_servers
-        ($env{'request.role.domain'});
+    my %host_servers = 
+	&Apache::lonnet::get_servers($env{'request.role.domain'},'library');
     if (! exists($host_servers{$env{'form.course_home'}})) {
         $r->print(&mt('Invalid home server for course').': '.
                   $env{'form.course_home'}.&Apache::loncommon::end_page());
@@ -689,7 +688,7 @@ sub create_course {
 # Flush the course logs so reverse user roles immediately updated
     &Apache::lonnet::flushcourselogs();
     $r->print('<p>'.&mt('Roles will be active at next login').'.</p>'.
-	      '<p><a href="/adm/createcourse">'.
+	      '<p><a href="/adm/createcourse?phase='.lc($crstype).'one">'.
 	      &mt('Create Another [_1]',$crstype).'</a></p>'.
 	      &Apache::loncommon::end_page());
 }
@@ -697,7 +696,7 @@ sub create_course {
 sub print_intro_page {
     my $r = shift;
     my $start_page =
-        &Apache::loncommon::start_page('Create a New Course');
+        &Apache::loncommon::start_page('Create a New Course or Group Space');
     my $crumbs = &Apache::lonhtmlcommon::breadcrumbs('Creation Options','Create_Course',undef,'Create_Courses');
     my $end_page =
         &Apache::loncommon::end_page();
@@ -708,11 +707,11 @@ sub print_intro_page {
                      short_description =>
     &mt('Create a new course by completing an online form.'),
                  },
-#                   { internal_name => 'groupone',
-#                     name => &mt('Create a single collaborative group space '),
-#                     short_description =>
-#    &mt('Create a new group space for non-course use by completing an online form .'),
-#                 },
+                   { internal_name => 'groupone',
+                     name => &mt('Create a single collaborative group space '),
+                     short_description =>
+    &mt('Create a new group space for non-course use by completing an online form .'),
+                 },
                    { internal_name => 'batchone',
                      name => &mt('Create courses/groups by uploading an attributes file'),
                      short_description =>
@@ -744,11 +743,11 @@ sub upload_batchfile {
     my $r = shift;
     my $start_page =
         &Apache::loncommon::start_page('Create a New Course or Group Space');
-    my $crumbs = &Apache::lonhtmlcommon::breadcrumbs('Upload Course Attributes File','Create_Course',undef,'Create_Courses');
+    my $crumbs = &Apache::lonhtmlcommon::breadcrumbs('Upload Course/Group Attributes File','Create_Course',undef,'Create_Courses');
     my $end_page =
         &Apache::loncommon::end_page();
     $r->print($start_page.$crumbs);
-    $r->print('<h3>'.&mt('Upload a courses attributes file').'</h3>');
+    $r->print('<h3>'.&mt('Upload a courses or groups attributes file').'</h3>');
     $r->print('<form name="batchcreate" method="post" '.
                 'enctype="multipart/form-data" action="/adm/createcourse">'.
               '<input type="file" name="coursecreatorxml" />'.
