@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # a pile of common html routines
 #
-# $Id: lonhtmlcommon.pm,v 1.156 2007/01/05 17:55:41 albertel Exp $
+# $Id: lonhtmlcommon.pm,v 1.159 2007/05/13 18:03:15 banghart Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -852,7 +852,7 @@ sub Create_PrgWin {
          popwin=open(\'\',\'popwin\',\'width=400,height=100\');".
         "popwin.document.writeln(\'".$start_page.
               "<h4>$heading<\/h4>".
-              "<form name=\"popremain\" method=\"post\">".
+              "<form action= \"\" name=\"popremain\" method=\"post\">".
               '<input type="text" size="'.$width.'" name="remaining" value="'.
 	      &mt('Starting').'" /><\\/form>'.$end_page.
               "\');".
@@ -864,7 +864,7 @@ sub Create_PrgWin {
 	$prog_state{'window'}='window';
 	if (!$formname) {
 	    $prog_state{'formname'}=&get_uniq_name();
-	    &r_print($r,'<form name="'.$prog_state{'formname'}.'">');
+	    &r_print($r,'<form action="" name="'.$prog_state{'formname'}.'">');
 	} else {
 	    $prog_state{'formname'}=$formname;
 	}
@@ -891,7 +891,7 @@ sub Create_PrgWin {
 # update progress
 sub Update_PrgWin {
     my ($r,$prog_state,$displayString)=@_;
-    &r_print($r,'<script>'.$$prog_state{'window'}.'.document.'.
+    &r_print($r,'<script type="text/javascript">'.$$prog_state{'window'}.'.document.'.
 	     $$prog_state{'formname'}.'.'.
 	     $$prog_state{'inputname'}.'.value="'.
 	     $displayString.'";</script>');
@@ -1002,13 +1002,14 @@ sub crumbs {
 		} 
 	    } else {
 		$path.='/'; 
-	    }
+	    }	    
             my $linkpath = &Apache::loncommon::escape_single($path);
             if ($form) {
 		$linkpath=
                     qq{javascript:$form.action='$linkpath';$form.submit();};
             }
-	    $output.=qq{<a href="$linkpath" $target>$dir</a>/};
+            my $href_path = &HTML::Entities::encode($path,'<>&"');
+	    $output.=qq{<a href="$path" $target>$dir</a>/};
 	}
     } else {
 	foreach my $dir (split('/',$uri)) {
@@ -1840,6 +1841,43 @@ sub set_form_elements {
     return $output;
 }
 
+##############################################
+##############################################
+
+# javascript_valid_email
+#
+# Generates javascript to validate an e-mail address.
+# Returns a javascript function which accetps a form field as argumnent, and
+# returns false if field.value does not satisfy two regular expression matches
+# for a valid e-mail address.  Backwards compatible with old browsers without
+# support for javascript RegExp (just checks for @ in field.value in this case). 
+
+sub javascript_valid_email {
+    my $scripttag .= <<'END';
+function validmail(field) {
+    var str = field.value;
+    if (window.RegExp) {
+        var reg1str = "(@.*@)|(\\.\\.)|(@\\.)|(\\.@)|(^\\.)";
+        var reg2str = "^.+\\@(\\[?)[a-zA-Z0-9\\-\\.]+\\.([a-zA-Z]{2,3}|[0-9]{1,3})(\\]?)$"; //"
+        var reg1 = new RegExp(reg1str);
+        var reg2 = new RegExp(reg2str);
+        if (!reg1.test(str) && reg2.test(str)) {
+            return true;
+        }
+        return false;
+    }
+    else
+    {
+        if(str.indexOf("@") >= 0) {
+            return true;
+        }
+        return false;
+    }
+}
+END
+    return $scripttag;
+}
+
 1;
 
 __END__
