@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Pick a course
 #
-# $Id: lonpickcourse.pm,v 1.60.2.2 2006/12/11 22:22:06 albertel Exp $
+# $Id: lonpickcourse.pm,v 1.63 2007/03/20 15:39:11 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -198,8 +198,8 @@ sub display_matched_courses {
             my ($descr,$instcode,$owner,$ttype) = split/:/,$courses{$course};
             $r->print(&course_chooser($multiple,$cdom,$cnum,$cleandesc));
             $r->print($description.'('.
-                      ($Apache::lonnet::domaindescription{$cdom}?
-                       $Apache::lonnet::domaindescription{$cdom}:$cdom).")");
+                      (&Apache::lonnet::domain($cdom,'description')?
+                       &Apache::lonnet::domain($cdom,'description'):$cdom).")");
             unless ($instcode eq '') {
                 $r->print(" - ".&unescape($instcode));
             }
@@ -279,8 +279,15 @@ sub build_filters {
             }
         }
         if ($item eq 'domainfilter') {
+	    my $allow_blank = 1;
+	    if ($formname eq 'portform') {
+		$filter->{$item} ||= $env{'user.domain'};
+		$allow_blank=0;
+	    }
             $domainselectform =
-     &Apache::loncommon::select_dom_form($filter->{$item},'domainfilter',1);
+		&Apache::loncommon::select_dom_form($filter->{$item},
+						    'domainfilter',
+						    $allow_blank);
         } elsif ($item eq 'ownerdomfilter') {
             $ownerdomselectform =
      &Apache::loncommon::select_dom_form($filter->{$item},'ownerdomfilter',1);
@@ -356,9 +363,9 @@ $multelement
     if ($domainselectform) {
         $output .= $lt{'cdo'}.': '.$domainselectform.'<br />'."\n";
     }
-#    if ($typeselectform) {
-#        $output .= $lt{'cog'}.': '.$typeselectform.'<br />'."\n";
-#    }
+    if ($typeselectform) {
+        $output .= $lt{'cog'}.': '.$typeselectform.'<br />'."\n";
+    }
     if ($instcodeform) {
         $output .= $lt{'cin'}.': '.$instcodeform.'<br />'."\n";
     }
