@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Simple Page Editor
 #
-# $Id: lonsimplepage.pm,v 1.49 2006/12/11 03:49:12 raeburn Exp $
+# $Id: lonsimplepage.pm,v 1.50 2007/05/02 01:33:49 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -266,8 +266,8 @@ sub handler {
 		      '<form method="post" enctype="multipart/form-data">'.
 		      '<input type="hidden" name="forceedit" value="edit" />'.
 		      '<h3>Upload a Photo</h3>'.
-		      '<input type="file" name="uploaddoc" size="50">'.
-		      '<input type="submit" name="storeupl" value="Upload">'.
+		      '<input type="file" name="uploaddoc" size="50" />'.
+		      '<input type="submit" name="storeupl" value="Upload" />'.
 		      '</form><form method="post">');
 	}
 	foreach my $field (sort(keys(%syllabusfields))) {
@@ -299,7 +299,7 @@ sub handler {
                             $r->print(
                                       '<br />Title<br /><textarea cols="80" rows="2" name="'.$field.'">'.
                                       &HTML::Entities::encode($syllabus{$field},'"&<>').
-                                      '</textarea><input type="submit" name="storesyl" value="Store" />');
+                                      '</textarea><input type="submit" name="storesyl" value="Save" />');
                         } else {
                             my $safeinit;
                             $r->print(&Apache::lonxml::xmlparse($r,'tex',$syllabus{$field},$safeinit));
@@ -325,7 +325,7 @@ sub handler {
 			if ($target ne 'tex') {
 			    $r->print('<br /><textarea cols="80" rows="24" name="'.$field.'" id="'.$field.'">'.
                                       &HTML::Entities::encode($syllabus{$field},'"&<>').
-				      '</textarea><input type="submit" name="storesyl" value="Store" />');
+				      '</textarea><input type="submit" name="storesyl" value="Save" />');
 			} else {
 			    my $safeinit;
 			    $r->print(&Apache::lonxml::xmlparse($r,'tex',$syllabus{$field},$safeinit));
