@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler to show and edit custom distribution rights
 #
-# $Id: lonrights.pm,v 1.21 2006/12/20 22:41:08 albertel Exp $
+# $Id: lonrights.pm,v 1.22 2007/05/02 01:34:23 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -305,7 +305,7 @@ ENDSTARTTABLE
   $r->print('</table>');
 # ------------------------------------------------------------ End table output
   if ($constructmode) { 
-     $r->print('<input type="submit" name="store" value="'.&mt('Store').'" /></form>'); 
+     $r->print('<input type="submit" name="store" value="'.&mt('Save').'" /></form>'); 
   }
   $r->print(&Apache::loncommon::end_page());
   return OK;  
